@@ -2,10 +2,10 @@ package Test2::AsyncSubtest::Hub;
 use strict;
 use warnings;
 
-our $VERSION = '0.000108';
+our $VERSION = '0.000112';
 
 use base 'Test2::Hub::Subtest';
-use Test2::Util::HashBase qw/ast_ids/;
+use Test2::Util::HashBase qw/ast_ids ast/;
 
 sub init {
     my $self = shift;
@@ -55,6 +55,16 @@ This is a subclass of L<Test2::Hub::Subtest> used for async subtests.
 
 You should not use this directly.
 
+=head1 METHODS
+
+=over 4
+
+=item $ast = $hub->ast
+
+Get the L<Test2::AsyncSubtest> object to which this hub is bound.
+
+=back
+
 =head1 SOURCE
 
 The source code repository for Test2-AsyncSubtest can be found at
@@ -78,7 +88,7 @@ F<https://github.com/Test-More/Test2-Suite/>.
 
 =head1 COPYRIGHT
 
-Copyright 2015 Chad Granum E<lt>exodist7@gmail.comE<gt>.
+Copyright 2018 Chad Granum E<lt>exodist7@gmail.comE<gt>.
 
 This program is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself.
