@@ -2,7 +2,7 @@ package Test2::Manual::Anatomy;
 use strict;
 use warnings;
 
-our $VERSION = '0.000108';
+our $VERSION = '0.000112';
 
 1;
 
@@ -34,19 +34,22 @@ L<Test2::API::Context> object works.
 
 =head1 THE API AND THE API INSTANCE
 
-COMING SOON.
-
-=head1 THE HUB STACK
-
-COMING SOON.
+The L<Test2::Manual::Anatomy::API> document explains the inner workings of the
+Test2 API.
 
 =head1 HUBS
 
-COMING SOON.
+The L<Test2::Manual::Anatomy::Hubs> document explains the inner working of
+the Test2 hub stack, and the hubs therein.
 
 =head1 THE IPC SYSTEM
 
-COMING SOON.
+The L<Test2::Manual::Anatomy::IPC> document describes the IPC system.
+
+=head1 INTERNAL UTILITIES
+
+The L<Test2::Manual::Anatomy::Utilies> document describes various utilities
+provided by the Test2 system.
 
 =head1 SEE ALSO
 
@@ -75,7 +78,7 @@ F<https://github.com/Test-More/Test2-Suite/>.
 
 =head1 COPYRIGHT
 
-Copyright 2017 Chad Granum E<lt>exodist@cpan.orgE<gt>.
+Copyright 2018 Chad Granum E<lt>exodist@cpan.orgE<gt>.
 
 This program is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself.
